Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/SymbSyntDec/SymbSyntDec.py | 98 | 81 | 0 | 17%
src/SymbSyntDec/__init__.py | 8 | 0 | 0 | 100%
src/SymbSyntDec/closure.py | 62 | 30 | 0 | 52%
src/SymbSyntDec/ground.py | 40 | 16 | 0 | 60%
src/SymbSyntDec/modify.py | 69 | 7 | 0 | 90%
src/SymbSyntDec/past.py | 18 | 13 | 0 | 28%
src/SymbSyntDec/pastSimple.py | 38 | 31 | 0 | 18%
src/SymbSyntDec/snf.py | 64 | 29 | 0 | 55%
src/SymbSyntDec/state_variables.py | 54 | 23 | 0 | 57%
src/__init__.py | 0 | 0 | 0 | 100%
tests/__init__.py | 1 | 0 | 0 | 100%
tests/test_modify.py | 126 | 10 | 0 | 92%
Total | 578 | 240 | 0 | 58%

No items found using the specified filter.